/***********************************************************************
* Distributional analysis of the impact of Covid in Africa
* Code written by Ani Rudra Silwal and Féraud Tchuisseu
* Last updated in May 2021
***********************************************************************/
	cls
	version 16.0
	discard
	macro drop _all
	clear all
    timer clear
	timer on 1
	set varabbrev on
	
	* Define macros
		global path "" // add your path here
		gl root "${path}/code" //code path
		gl data "${path}/data" // data path. Note: not included in the public reproducibility package
		gl GMDdata "${data}\01_Input\GMD"
		*gl hfps "_borrar_Dec16"
		gl hfps "_borrar_Jun30_nodups"
		gl HFPSdata "${data}/01_Input/Completed HFPS Datasets SSA/$hfps"
		gl HFPSdataAfrica "${data}/03_Output/${hfps}_Africa"
		gl output "${data}/03_Output"
		*gl ccc BFA //Runtime: ~10 min
		gl ccc /* Countries in final analysis */ BFA ETH GAB  GHA GMB MLI MOZ MWI NER NGA SEN SLE UGA ZWE //Runtime: ~30 min // SDN RWA
		glo vlist1 /* variables for S2S imputation */ code wave hid weight marital hhsize children_share elderly_share subnatid urban year month educat4 relation age male 
		glo vlist2 /* outcome variables in HFPS */ Asse_drink Asse_intern Asse_soap Asse_wash Copi_reduce Copi_sold Copi_used Demo_Dratio Demo_educ1 Demo_educ2 Demo_educ3 Demo_educ4 Demo_hsize Demo_male Educ_any Educ_atte Educ_comp Educ_mobi Educ_other Educ_teacher Educ_radio Educ_tvprog Fina_access Fina_reason1 Fina_reason2 Fina_reason3 FS_unable FS_ateless FS_atefew FS_day FS_hungry FS_skipmeal FS_ranout FS_worried Heal_need Heal_rece Heal_reason1 Heal_reason2 Heal_reason3 Heal_reason4 Heal_reason5 Heal_reason6 Heal_reason7 Heal_reason8 Heal_reason9 Hous_ablepayre Hous_moved Hous_own Hous_rooms Inco_ToD_prew Inco_ToI_prew Inco_redremitt_prew Inco_remitt_prew Inco_FaLI_prew Inco_FaLD_prew Inco_NfLI_prew Inco_NfLD_prew Inco_WaLI_prew Inco_WaLD_prew Inco_ToD_prey Inco_ToI_prey Inco_redremitt_prey Inco_remitt_prey Inco_FaLI_prey Inco_FaLD_prey Inco_NfLI_prey Inco_NfLD_prey Inco_WaLI_prey Inco_WaLD_prey Inco_changeToD Inco_changeToI Inco_redremitt Inco_remitt Inco_FachangenLI Inco_FachangenLD Inco_NfchangenLI Inco_NfchangenLD Inco_WachangenLI Inco_WachangenLD Know_any_other Know_any Know_other Know_heard Know_curfew Know_dissemi Know_food Know_closing Know_stay Know_travel Labo_chang_prew Labo_chang Labo_empl Labo_farm Labo_nonfarm Labo_nonormalf Labo_notusual Labo_part Labo_partnotusual Labo_selfemp Labo_employee Labo_nonemployee Labo_stop Labo_stop_prew Prev_AP_other Prev_other Prev_AnyPrev Prev_gatherings Prev_distancing Prev_handshakes Prev_handwash Prev_masks Prev_AS_other Prev_AnyStaple Prev_Sfood_other Prev_Sfood1 Prev_Sfood2 Prev_Sfood3 Safe_anysource_prew Safe_gover_prew Safe_tried_prew Safe_anysource Safe_gover Safe_tried Subj_better Subj_concer Subj_satis Subj_worse Safe_coverjob Safe_coverfood	
		glo vlist $vlist1 $vlist2
		
	* Ado folders
		sysdir set PLUS "${root}/02_programs/ado"
		adopath + "${root}/02_Programs"
		mata: mata mlib index
		cd "$root" 
		
	* Prepare data for analysis
		 do "$root\02_Programs\02_Summarize_HFPS.do" // temporary 
		
	* Implement S2S imputation
		do "$root\02_Programs\03_S2S.do"
		
	* Compile results and generate graphs
		do "$root\02_Programs\07_Compare_HFPS_GMD.do"
		do "$root\02_Programs\08_Graphs_by_quintiles.do"
		do "$root\02_Programs\09_Graphs_of_evolution_of_impact.do"

	
    timer off 1
    timer list
