*** Prepare data for analysis

***********************************************************	
* Program to keep African countries in HFPS survey
***********************************************************	
	cap program drop keepAfrica
	program define keepAfrica
			#delim ;
			gen africa=regexm(code,"^(AGO|BDI|BEN|BFA|BWA|CAF|CIV|CMR|COD|COG|COM|CPV|
			ERI|ETH|GAB|GHA|GIN|GMB|GNB|GNQ|KEN|LBR|LSO|MDG|MLI|MOZ|MRT|MUS|MWI|NAM|NER|NGA|
			RWA|SDN|SEN|SLE|SOM|SSD|STP|SWZ|SYC|TCD|TGO|TZA|UGA|ZAF|ZMB|ZWE|)$");
			#delim cr
			drop if africa==0
			drop africa
	end
***********************************************************	

use "$HFPSdata" , clear	

* UGA wave 2: hid is not unique so we exclude it from the analysis : fixed in August version

/*
keepAfrica
drop if code=="UGA" & wave=="WAVE2"
replace wave="WAVE2" if code=="UGA" & wave=="WAVE3"
replace wave="WAVE3" if code=="UGA" & wave=="WAVE4"
*/

* Create a survey-month variable
	drop if month==0
	gen yyyymm=.
	replace yyyymm = 12*(year-2020)+month-3 
	/*replace yyyymm = 1 if year==2020 & month==4
	replace yyyymm = 2 if year==2020 & month==5
	replace yyyymm = 3 if year==2020 & month==6
	replace yyyymm = 4 if year==2020 & month==7
	replace yyyymm = 5 if year==2020 & month==8
	replace yyyymm = 6 if year==2020 & month==9
	replace yyyymm = 7 if year==2020 & month==10
	replace yyyymm = 8 if year==2020 & month==11
	replace yyyymm = 9 if year==2020 & month==12
	replace yyyymm = 10 if year==2021 & month==1
	replace yyyymm = 11 if year==2021 & month==2
	*/ 
	lab var yyyymm "Number of months from March-2020"
	ta yyyymm
	ta yyyymm month
	tempfile main1
	save `main1'

* Drop variables with very few observations
	clear
	tempfile main2
	save `main2', replace emptyok
	foreach c of glo ccc{ //loop through countries
		use `main1',clear
		order subnatid1 wave , before(hh_moved)
		drop agecat acce_he_other acce_children_espec *file *FCV Geog* countrycode Lending_Category vac_concern_other vac_concern_oth vac_avail_other vac_type_other vac_register_other vac_location_other vac_difficult_other
		* Comment out the next line if you are unsure of which countries should be included in this analysis
		di "`c'"
		keep if code=="`c'"
		qui foreach v of varlist hh_moved-uno{  //loop through vars
			di "`v'"
			count 
			loc a = r(N)
			count if !mi(`v')
			loc b = r(N)
			replace `v'=. if `b'/`a'<.1 | `b'<30 //Keep only vars if >10% of obs are non-missing. This rule is rather arbitrary.
			replace `v'=. if `v'<0
		}
		qui append using `main2'
		save `main2', replace
	}
	cls
	keep code wave $vlist yyyymm
	*codebook, c
	
	keep if inlist(code, "BFA", "ETH", "GAB", "GHA", "MLI", "MOZ", "MWI", "NGA", "SEN") | inlist(code, "SLE", "UGA", "ZWE") | inlist(code, "GIN", "GMB", "NER","SDN","RWA")
	save "$data\03_Output\\${hfps}_Africa", replace
	gl HFPSdataAfrica "$data\03_Output\\${hfps}_Africa"

* Find sample size of HFPS waves used in this analysis
	u "$HFPSdataAfrica", clear
	keep code wave
	gen n=1
	collapse (sum)n, by(code wave)
	reshape wide n, i(code) j(wave) string	
	li
	
* Find the latest wave of HFPS for each country:
	u "$HFPSdataAfrica", clear
	keep code wave
	gen x=subinstr(wave,"WAVE","",1)
	destring x, force gen(y)
	egen z=max(y), by(code)
	keep code z
	duplicates drop
	sort code
	ren z lastWave
	keepAfrica
	save "$data\03_Output\lastWave", replace
		
* Examine which variables are available for analysis in HFPS data
	glo coreVars hhsize children_share elderly_share subnatid urban 
	glo outcomeVars $vlist2
	glo allVars $coreVars $outcomeVars

	*use "$HFPSdataAfrica",clear
	use "$HFPSdata" , clear
	keepAfrica
	*drop if wave=="WAVE10"
	*drop subnat*
	tempfile main
	save "`main'"

	levelsof code, clean
	gl clist =r(levels)
	di "$clist"
	local r: word count $clist
	local c: word count $allVars

	loc k=0
	loc wave=10
	foreach var in $allVars{
		dis "`var'"
		/*if "`var'"=="Demo_hsize" {
			set trace on 
			set traced 1
		}*/ 
		loc ++k
		if `k'<2 {
			loc cell=2 
			loc cellplus=`cell'+1
		}

		
		
		mat table`var'=J(`r',`wave',.)
		mat table_reg =J(`r',`wave',.)
		mat table_out =J(`r',`wave',.)
		mat rownames table`var' = $clist
		mat colnames table`var' = Wave1 Wave2 Wave3 Wave4 Wave5 Wave6 Wave7 Wave8 Wave9 Wave10 // Wave11 Wave12 Wave13 Wave14
		loc i=0
		 
		foreach ccc in $clist{
			use if code=="`ccc'" using "`main'", clear
			qui gen _temp=substr(wave,5,1)
			qui destring _temp,replace
			qui su _temp
			loc number_wave`ccc'=r(max)  // number of HFPS waves for this country
			tempfile data
			* qui save `data',replace
			qui save "$data/data_temp",replace
			loc ++i
			forval w=1(1)`wave'{
				if  `w'<=`number_wave`ccc'' {
					*use `data',clear
					use "$data/data_temp",clear
					qui keep if  wave== "WAVE`w'"
					qui su `var'
					mat table`var'[`i',`w']=r(N)>0
					if "`var'"=="subnatid"{ //summarize doesn't work for strings, so we make an exception
						tempvar x
						encode subnatid, gen(`x')
						qui su `x'
						mat table`var'[`i',`w']=r(N)>0
					}
					mat table_reg[`i',`w']=0
					mat table_out[`i',`w']=0
					
				}
				
			}
		}
		
	* Export results of individual variables 
			local lab: variable label `var' 	
			qui putexcel set "${output}\HFPS_wave_summary.xlsx", sheet("sheet2") modify
			qui putexcel A1=("1 if the variable is available in the survey wave, 0 otherwise")
			qui putexcel A`cell'=("`var'")
			qui putexcel A`cellplus'=matrix(table`var') , names
			loc cell=`cell'+30
			loc cellplus=`cell'+1
	}

	foreach var in $coreVars{
		*mat list table`var'
		mat table_reg= table_reg + table`var'
	}
		mat list table_reg

	foreach var in $outcomeVars{
		
		mat table_out=table_out + table`var'
	}
	mat li table_out

	qui putexcel set "${output}\HFPS_wave_summary.xlsx", sheet("sheet1") modify
	qui putexcel A2="Core variables, used to model consumption for S2S imputation, available in HFPS wave"
	qui putexcel A3=matrix(table_reg) , names
	qui putexcel A29="Outcome variables available in HFPS wave"
	qui putexcel A30=matrix(table_out) , names	
