* Derive necessary variables for analysis in GMD and HFPS

	************************************
	*** Find the relevant GMD file for the country in question
	************************************

	* Make a list of surveys in the input folder
		local files : dir "$GMDdata" files "*.dta"
		foreach file in `files' {
			glo GMD_file_temp=upper("`file'")
			glo c=substr("$GMD_file_temp",1,3)
			if "$c"=="$Country_code"{
			di "$c"
			    glo GMD_file "$GMD_file_temp"
				qui u "$GMDdata\\$GMD_file", clear
				di "$c $gmdSurvName $gmdSurvYr $GMD_file"
			}
		}

	di "$GMD_file"


	************************************
	*** Generate relevant variables in GMD and HFPS
	************************************

	cap mkdir  "${root}\03_Output\\${Country_code}"
	cap cd "${root}\03_Output\\${Country_code}"


	 * GMD	data 
	use "$GMDdata\\${GMD_file}",clear
	
	// dlw, coun(${Country_code}) y(`GMD_survey_year') t(GMD) mod(ALL) verm(01) vera(`veralt') sur(`GMD_survey_name')
	cap drop phone
	* if some vars doesn't exist, create them
	foreach v in cellphone int_month subnatid urban age male relationharm marital lstatus industrycat10 occup educat4{
		di "`v'"
		cap confirm var `v'
		if _rc gen `v'=. 
	}
	ren cellphone phone  
	lab var phone "Ownership of mobile phone"
	ren hhid hid
	
	keep hid pid int_month weight_h weight_p welfare hsize  ///
	subnati*  urban age male relationharm marital lstatus industrycat10 occup ///
	educat4  phone  
	
	* Log welfare per capita
	gen log_welfare=log(welfare)
	lab var log_welfare "Log of per capita household consumption "
	
	*Type of Harmonization
	gen Harmonization=0
	lab var Harmonization "Type of Harmonization"
	lab def Harmonization 0 "GMD" 1 "HFPS-WAVE${wave}"
	lab val Harmonization Harmonization
	
	* The subnatid variable needs to be tweaked for some countries
		glo c_dep=0
		* Nigeria
		if "${Country_code}"== "NGA" {
			encode subnatid2, gen(departement)
			replace departement=37 if departement==36
			glo c_dep=$c_dep+1
			di "yes `c_dep'"
			
		} // end if
		* Ethiopia 
		if "${Country_code}"== "ETH" {
			encode subnatid, gen(departement)
			glo c_dep=$c_dep+1
		} // end if
		* Zambia 
		if "${Country_code}"== "ZMB" {
			encode subnatid, gen(departement)
			glo c_dep=$c_dep+1
		} // end if
		* Malawi
		if "${Country_code}"== "MWI"{
			gen departement=substr(subnatid2,1,3)
			destring departement,replace force
			glo c_dep=$c_dep+1
		} // end if
		if "${Country_code}"== "SLE"{
			encode subnatid2, gen(departement)
			destring departement,replace
			glo c_dep=$c_dep+1
		} // end if
		if "${Country_code}"== "MOZ"{
			encode subnatid2, gen(departement)
			destring departement,replace
			glo c_dep=$c_dep+1
		} // end if
		if "${Country_code}"== "BFA"{
			encode subnatid1, gen(depar)
			recode depar (1=6)(2=13)(3=12)(4=7)(5=9)(6=4)(7=3)(8=2)(9=10)(10=11)(11=5)(12=8)(13=1),gen(departement)
			glo c_dep=$c_dep+1
		} // end if
		if "${Country_code}"== "SDN"{
		encode subnatid1, gen(depar)
		recode depar (1=10) (2=1) (3=8) (4=2) (5=6) (6=17) (7=13) (8=15) (9=12) (10=5) (11=4) (12=7) (13=16) (14=18) (15=9) (16=3) (17=14) (18=11),gen(departement)
		glo c_dep=$c_dep+1
		} // end if
		if "${Country_code}"== "NER" | "${Country_code}"== "GIN"| "${Country_code}"== "RWA" {  // to modify
			encode subnatid1, gen(departement)
			glo c_dep=$c_dep+1
		} // end if

		if "${Country_code}"== "MLI"{
			encode subnatid1, gen(depar)
			recode depar (1=3)(2=10)(3=6)(4=5)(5=8)(6=9)(7=7)(8=11)(9=2)(10=4)(11=1),gen(departement)
			glo c_dep=$c_dep+1
		} // end if
		if "${Country_code}"== "SEN"{
			encode subnatid1, gen(departement)
			glo c_dep=$c_dep+1
		} // end if
		if "${Country_code}"== "TCD"{
			encode subnatid1, gen(depar)
			recode depar (15=16)(16=17)(17=18)(18=19)(19=20)(20=21)(21=22),gen(departement)
			glo c_dep=$c_dep+1
		} // end if		
		if $c_dep==0 {
			gen departement=.
		}
	lab var departement "1st level of administrative unit"
		
	gen hhsizeSq=hsize*hsize
	label var hhsizeSq "Household size, squared"
	
	* Household age composition
	gen child=age<15 if !mi(age)
	gen elder=age>65 if !mi(age)
	bysort hid: egen children_number = sum(child)
	bysort hid: egen elderly_number = sum(elder)
	label var children_number "Number of HH members less than 15 years old"
	label var elderly_number "Number of HH members more than 65 years old"
	
	ren weight_h weight
	ren hsize hhsize
	
	
	* Head age
	gen head=relationharm==1 if !mi(relationharm)
	gen headag=age*head
	bysort hid : egen headage=max(headag)
	replace headage=. if headage==0 
	lab var headage "HH head age" 
	
	* Gender of household head
	recode male (0=1)(1=0),gen(female)
	gen fhead=female*head==1
	bysort hid : egen femhead=max(fhead)
	lab var femhead "HH head is female" 
	lab def femhead 1 "Yes" 0 "No"
	
	* Head or spouse (individual is head or spouse)
	gen head_spouse= inlist(relationharm,1,2) if !mi(relationharm)
	lab var head_spouse "Individual is head or spouse" 
	lab def head_spouse 1 "Yes" 0 "No"
	
	* Head educat4 level
	gen headedu=educat4 if head ==1
	bysort hid : egen head_educat4=max(headedu)
	lab var head_educat4 "Highest level of education completed (4 categories)"
	sort hid relationharm
	
	* Create a matrix of HH characteristics
	bysort hid : egen hhsize2=count(pid) // Number of HH member in the GMD data
	gen children_share=children_number/hhsize2
	gen elderly_share=elderly_number/hhsize2
	gen literate =educat4>1 if !mi(educat4)
	local varcharc   hhsize urban  children_share  elderly_share  phone  ///
	male age head literate femhead head_educat4 headage head_spouse
	matrix MAT_HH_GMD_${Country_code} = J(13,5,.)
	matrix MAT_HH_GMD_${Country_code}_phone = J(13,5,.)
	matrix colnames MAT_HH_GMD_${Country_code}=Mean "Standard deviation" Min Max "Sample size"
	matrix rownames MAT_HH_GMD_${Country_code}= "Household Size"  "Urban (household)"  "Children share" "Elderly share" ///
	"Ownership of phone"  "Male" "Age (respondent)" "Household Head" "Literate" ///
	"HH head is female" "HH head Educat4" "HH head age" "Individual is head or spouse"
	matrix colnames MAT_HH_GMD_${Country_code}_phone=Mean "Standard deviation" Min Max "Sample size"
	matrix rownames MAT_HH_GMD_${Country_code}_phone=  "Household Size" "Urban (household)" "Children share" "Elderly share" ///
	"Ownership of phone"  "Male" "Age (respondent)" "Household Head" "Literate" "HH head is female" "HH head Educat4" "HH head age" "Individual is head or spouse"
	local i1=0
	foreach v of local varcharc {
		local ++i1
		qui su `v' [aw=weight]
		matrix MAT_HH_GMD_${Country_code}[`i1',1]=r(mean)
		matrix MAT_HH_GMD_${Country_code}[`i1',2]=r(sd)
		matrix MAT_HH_GMD_${Country_code}[`i1',3]=r(min)
		matrix MAT_HH_GMD_${Country_code}[`i1',4]=r(max)
		matrix MAT_HH_GMD_${Country_code}[`i1',5]=r(N)
		
		qui su `v' [aw=weight] if phone==1 // only  phone owners
		matrix MAT_HH_GMD_${Country_code}_phone[`i1',1]=r(mean)
		matrix MAT_HH_GMD_${Country_code}_phone[`i1',2]=r(sd)
		matrix MAT_HH_GMD_${Country_code}_phone[`i1',3]=r(min)
		matrix MAT_HH_GMD_${Country_code}_phone[`i1',4]=r(max)
		matrix MAT_HH_GMD_${Country_code}_phone[`i1',5]=r(N)
	} //end foreach	 
	matrix list MAT_HH_GMD_${Country_code}
	matrix list MAT_HH_GMD_${Country_code}_phone
	
	* Export in excel the table in excel
	putexcel set "${root}\03_Output\\HFPS_Results_HH_WAVE${wave}.xlsx", sheet("$Country_code") modify
	putexcel K1=("GMD")
	putexcel K3=matrix(MAT_HH_GMD_${Country_code}) , names
	putexcel R1=("GMD phone")
	putexcel R3=matrix(MAT_HH_GMD_${Country_code}_phone) , names
	
	* keep one observation per HH for HH model
		sort hid relationharm	
		by hid : keep if _n==1
	
	cap tostring hid, force replace
	ren relationharm relation
	keep hid int_month weight Harmonization  urban log_welfare welfare hhsize hhsizeSq  ///
	children_share elderly_share departement headage femhead head_educat4  phone relation

	tempfile Clean_GMD
	save `Clean_GMD'

	
	************************************
	*** HFPS	
	************************************
	use "$HFPSdataAfrica",clear
	keep if code=="$Country_code" & wave=="WAVE${wave}"
	qui count if hid~=""  // only drop missings if some are not missing 
	if r(N)==0 {
	replace hid=string(_n)
	}
	drop if hid=="." | mi(hid)
	*Type of Harmonization
	gen Harmonization=1
	lab var Harmonization "Type of Harmonization"
	lab def Harmonization 0 "GMD" 1 "HFPS-WAVE${wave}"
	lab val Harmonization Harmonization
	
	* region variable
		* Malawi
		 if "${Country_code}"== "MWI"{
			gen departement=substr(subnatid1,1,3)
			destring departement,replace
		 } // end if
		 else {
			encode subnatid1, gen(departement)
		 }
	lab var departement "1st level of admistratine unit"
	
	* hhsize square
	gen hhsizeSq=hhsize*hhsize
	label var hhsizeSq "Household size, squared"

	ren month int_month
		* literate
	gen literate =educat4>1 if !mi(educat4)
	
		* Head age
	gen head=relation==1
	gen headage=age*head 
	replace headage=. if headage==0 
	lab var headage "HH head age" 
	
	* Gender of household head
	recode male (0=1)(1=0),gen(female)
	gen femhead=female*head==1
	lab var femhead "HH head is female" 
	
	* Head or spouse (respondent is head or spouse)
	gen head_spouse= inlist(relation,1,2) if !mi(relation)
	lab var head_spouse "Respondent is head or spouse" 
	lab def head_spouse 1 "Yes" 0 "No"
	
	* Head educat4 level
	gen head_educat4=educat4 if head ==1
	lab var head_educat4 "Highest level of education completed (4 categories)"
	
	* Cell phone ownership
	gen phone=1
	lab var phone "Ownership of mobile phone"
	
	keep code hid int_month weight Harmonization urban  hhsize hhsizeSq ///
	children_share elderly_share age departement head headage femhead head_educat4 ///
	 phone male literate head_spouse age educat4 relation children_share elderly_share
	
	* Respondent and household characteristics in HFPS
	local varcharc   hhsize urban  children_share  elderly_share  phone  ///
	male age head literate femhead head_educat4 headage head_spouse
		matrix MAT_HH_HFPS_${Country_code} = J(13,5,.)
		matrix colnames MAT_HH_HFPS_${Country_code}=Mean "Standard deviation" Min Max "Sample size"
		matrix rownames MAT_HH_HFPS_${Country_code}= "Household Size" "Urban (household)" "Children share" "Elderly share" ///
	"Ownership of phone"  "Male" "Age (respondent)" "Household Head" "Literate" "HH head is female" "HH head Educat4" "HH head age" "Respondent is head or spouse" 
	
	* create a size variable: 1 for ind var, and hhsize for HH var, to be used in weight
		local varcharc_hh   hhsize urban  children_share  elderly_share  phone 
		foreach v of local varcharc {
			gen size`v'=1
		} //end foreach
		foreach vh of local varcharc_hh {
			replace size`vh'=hhsize
		} //end foreach
	
	
	local i=0
	foreach v of local varcharc {
		local ++i
		qui su `v' [aw=weight*size`v']
		matrix MAT_HH_HFPS_${Country_code}[`i',1]=r(mean)
		matrix MAT_HH_HFPS_${Country_code}[`i',2]=r(sd)
		matrix MAT_HH_HFPS_${Country_code}[`i',3]=r(min)
		matrix MAT_HH_HFPS_${Country_code}[`i',4]=r(max)
		matrix MAT_HH_HFPS_${Country_code}[`i',5]=r(N)
	} //end foreach

	matrix list MAT_HH_HFPS_${Country_code}
	
	* Export in excel the table in excel
	putexcel set "${root}\03_Output\\HFPS_Results_HH_WAVE${wave}.xlsx", sheet("$Country_code") modify
	putexcel Y1=("HFPS")
	putexcel Y3=matrix(MAT_HH_HFPS_${Country_code}) , names

	
	keep code hid int_month weight Harmonization  urban hhsize hhsizeSq  ///
	children_share elderly_share departement headage femhead head_educat4  phone 

	* keep one observation per HH for HH model
	duplicates drop //convert individual-level dataset to household-level dataset

	
	* Append GMD and HFPS	
	append using `Clean_GMD',force


	save "$data/Merge_GMD_HFPS_${Country_code}_HH_WAVE${wave}",replace