* Imputation model

	cap mkdir  "${root}\03_Output\\${Country_code}"
	cap cd "${root}\03_Output\\${Country_code}"
	*cap log close _all
	*log using "${Country_code}_s2s_imputation_log_HH", replace  // name(${Country_code}_s2s_imputation_log)

	use "$data/Merge_GMD_HFPS_${Country_code}_HH_WAVE${wave}", clear
	preserve
	
	* Normalize variables
	loc var_to_norm log_welfare welfare  hhsizeSq children_share elderly_share 
	foreach x of local var_to_norm {
		su `x'
		replace `x'=(`x'-r(mean))/r(sd)
	}
	su hhsize
	
	gen hsize=(hhsize-r(mean))/r(sd)

	
	* Model of consumption
	if $c_dep>0 {
		local location i.urban    i.departement 
	}
	if $c_dep==0 {
		local location i.urban  
	} // end if
	
	local demographics hsize hhsizeSq  children_share elderly_share  // i.femhead  headage headageSq i.head_educat4
	local assets phone // television radio mobilePhone landLine fridge computer internet bicycle motorcycle car
	local interaction c.phone#c.hsize c.phone#c.hhsizeSq c.phone#c.children_share c.phone#c.elderly_share c.phone#i.departement ///
	c.hsize#i.urban   c.hsize#c.children_share ///
	c.hsize#c.elderly_share  c.hhsizeSq#i.urban   c.hhsizeSq#c.children_share ///
	c.hhsizeSq#c.elderly_share i.urban#c.children_share i.urban#c.elderly_share ///
	i.departement#c.children_share i.departement#c.elderly_share c.hsize#i.departement c.hhsizeSq#i.departement i.departement#c.elderly_share
	local alwaysvars  `location' `demographics' 
	local othervars `interaction' `assets' 
	
	* qui lasso linear  log_welfare `alwaysvars' `othervars' [iw= weight * hhsize ]  if Harmonization==0  , rseed(12345)   
	qui lasso linear  log_welfare `alwaysvars' `othervars' [iw= weight * hhsize ]  if Harmonization==0  , rseed(12345) selection(bic, postselection)  
	glo allvars_sel `e(allvars_sel)'
	di "$allvars_sel"

	lassoXcheck, vlist("$allvars_sel")
	di r(allvars_sel_new)
	restore // restore preview data because some variable were normalized
	gen hsize=hhsize
	
	reg log_welfare `r(allvars_sel_new)'  if Harmonization==0 [aweight= weight * hhsize ]
	* Export to Excel
		putexcel set "${root}\03_Output\\HFPS_Results_HH_WAVE${wave}.xlsx", sheet("$Country_code") modify
		putexcel AF1="S2S estimation model:"
		putexcel (AF3) = etable
		loc nobs=e(N)
		loc adjRsq=e(r2_a)
		putexcel AI1=("N: ")
		putexcel AJ1=`nobs'
		putexcel AK1=("Adj. R-squared: ")
		putexcel AL1=`adjRsq'
		
	predict log_welfare_hat, xb
	gen welfare_hat=exp(log_welfare_hat)
	
	* check densities 
	twoway (kdensity log_welfare if Harmonization==0 [aw=weight * hhsize],lwidth(medthick) ) ///
	(kdensity log_welfare_hat if Harmonization==0  [aw=weight * hhsize],lwidth(medthick) lpattern(dash)) ///
	(kdensity log_welfare_hat if Harmonization==1  [aw=weight * hhsize],lwidth(medthick) lpattern(dash_dot)), ///
	xtitle(Log of per capita household consumption) ytitle(Density) ///
	legend(order( 1 "GMD (actual)"  2 "GMD (predicted)" 3 "HFPS (predicted)") ) title(Kdensity ${Country_code})
	graph export "Kdensity_${Country_code}_HH_WAVE${wave}.png",replace
	
	
	*** Compare actual vs. predicted quintiles in GMD

	* Create quintile of actual GMD data
		xtile quintileGMDtrue =welfare [aw=weight * hhsize] if Harmonization==0, nq(5)	
			

	* Create quintile of predicted GMD data
		xtile quintileGMDhat =welfare_hat [aw=weight * hhsize] if Harmonization==0, nq(5)	
		xtile percentileGMDhat =welfare_hat [aw=weight * hhsize] if Harmonization==0, nq(100)
		
			* Save GMD file with actual & predicted quintiles
			preserve
			keep if Harmonization==0
			save "$data/${Country_code}_GMD_with_predicted_welfare.dta",replace
			restore
			
	* Generate welfare quintiles in the GMD dataset
	pctile welfare_pct = welfare_hat  [aw=weight * hhsize] if Harmonization==0, nq(100)  genp(percent)
	xtile quintileGMD =welfare_hat [aw=weight * hhsize] if Harmonization==0, nq(5)
	xtile percentileGMD =welfare_hat [aw=weight * hhsize] if Harmonization==0, nq(100)
			preserve
			keep if  Harmonization==0
			* Tabulate true and predicted quintiles in GMD (weighted)

				ta quintileGMDtrue quintileGMDhat [aw=wei] 
				ta quintileGMDtrue quintileGMDhat [aw=wei], matcell(m)
				mat li m
			* Tabulate true and predicted quintiles in GMD (unweighted)
				ta quintileGMDtrue quintileGMDhat
				ta quintileGMDtrue quintileGMDhat, matcell(n)
				mat li n
			* Export in excel
				putexcel set "${root}\03_Output\\HFPS_Results_HH_WAVE${wave}.xlsx", sheet("$Country_code") modify
				putexcel K21=("Compare actual and predicted welfare Quintiles")
				putexcel K22=("With weight")
				putexcel K23=matrix(m) , names
				putexcel K29=("Without weight")
				putexcel k30=matrix(n) , names
			restore 
			
	* Create welfare Quintile in the HFPS data
	gen Quintile=.
	qui replace Quintile=1 if welfare_hat<=welfare_pct[20]  
	qui replace Quintile=2 if welfare_hat>welfare_pct[20]   & welfare_hat<=welfare_pct[40] 
	qui replace Quintile=3 if welfare_hat>welfare_pct[40]   & welfare_hat<=welfare_pct[60] 
	qui replace Quintile=4 if welfare_hat>welfare_pct[60]   & welfare_hat<=welfare_pct[80] 
	qui replace Quintile=5 if welfare_hat>welfare_pct[80] 
	*tab Quintile  [aw=weight * hhsize]  if Harmonization==0,mi // GMD
	tab quintileGMD  [aw=weight * hhsize]  if Harmonization==0,mi // GMD
	tab Quintile  [aw=weight * hhsize]  if Harmonization==1,mi // HFPS


	* Classifying HFPS hh in different GMD welfare  percentiles
	gen Percentile=.
	qui replace Percentile=1 if welfare_hat<=welfare_pct[1] 
	qui replace Percentile=100 if welfare_hat>welfare_pct[99] 
	forvalues i=2(1)99 {
		qui replace Percentile=`i' if welfare_hat>welfare_pct[`i'-1]   & welfare_hat<=welfare_pct[`i'] 
	} // end forvalues
	

	* Create new HFPS data with estimated welfare and Quintiles
	keep if Harmonization==1
	keep hid Quintile Percentile welfare_hat log_welfare_hat
	isid hid
	capture confirm numeric variable hid
	 if !_rc {
		ren hid hhid
		tostring(hhid), gen(hid)
     }
	 gen code ="${Country_code}"
	preserve 
		use "$HFPSdataAfrica",clear
		keep if code=="$Country_code" & wave=="WAVE${wave}"
		drop if hid=="." | mi(hid)
		tempfile hfps
		save `hfps'
	restore
	merge 1:1 hid using `hfps',nogen
	*glo model2=subinstr("$model","_","",.)
	save "$data/03_Output\HH_${Country_code}_New_HFPS_WAVE${wave}.dta",replace 
	
	cap log close
	graph close _all