***********************************************************************
* lassoXcheck.ado 
* This ado ensures that all interactions have main effects selected after lasso is implemented
* Reference: Chen, K., Li, W. and Wang, S., 2020. An Easy-to-Implement Hierarchical Standardization for Variable Selection under Strong Heredity Constraint.
* input: allvars_sel from lasso output
* output: allvars_sel_new
***********************************************************************

cap program drop lassoXcheck
program define lassoXcheck, rclass
	version 16.0
	syntax, vlist(string) 
	preserve
	
*** Keep only interaction terms in allvars_sel
	loc n_var : word count `vlist'
	glo int_sel ""
	forval i=1(1)`n_var' {
	loc this_name`i' = "`:word `i' of `vlist''"
		if regexm("`this_name`i''", "#") == 1 {
			glo int_sel $int_sel `this_name`i''
		}
	}
	*di "$int_sel"

*** Remove irrelevant characters from allvars_sel
	glo int_sel1=subinstr("$int_sel","#"," ",.)
	di "$int_sel1"
	glo int_sel1=subinstr("$int_sel1","c."," ",.)
	di "$int_sel1"
	glo int_sel1=subinstr("$int_sel1","."," ",.)
	di "$int_sel1"

*** Create a list of variables in the interaction terms
	loc n_var : word count $int_sel1
	loc int_varlist ""
	forval i=2(1)`n_var' {
		loc this_name`i' = "`:word `i' of $int_sel1'"
		loc ii=0 
		qui gen _fisrt_char=substr("`this_name`i''",1,1)
		forval kk=0(1)9{
			 if _fisrt_char=="`kk'"{
			   loc ++ii
			 }  // end if
		} // end forval
		loc k=`i'-1
		forval j=1(1)`k' {
			if "`this_name`j''"=="`this_name`i''" {
				loc ++ii
			}  // end if
		} // end forval
		
		if `ii'==0 {
			loc int_varlist `int_varlist' `this_name`i''
			di "`var1'"
		} // end if
		drop _fisrt_char*
	}

*** Check if variables within interactions are also included as levels

	* Isolate list of variables used as levels from allvars_sel
	loc int_sel = "$int_sel"
	loc allvars_sel = "`vlist'"
	loc lev_varlist : list allvars_sel - int_sel
	loc lev_varlist=subinstr("`lev_varlist'","0bn.","",.)
	loc lev_varlist=subinstr("`lev_varlist'","1bn.","",.)
	loc added_vars = ""
	
	*di "`allvars_sel'"
	*di "$int_sel"
	*di "`int_sel'"
	*di "`lev_varlist'"
	
*** Check if elements of int_varlist are also in lev_varlist; expand allvars_sel if necessary
	di "`allvars_sel'" //before adding new elements
	foreach i of loc int_varlist{
	di "`i'"
	if `: list i in lev_varlist' { 
			 di "`i' is in lev_varlist, so won't be added to allvars_sel" 
		 } 
		else {
			di "`i' is not in lev_varlist, so will be added to allvars_sel" 	
			loc allvars_sel `i' `allvars_sel'
			loc added_vars `i' `added_vars'
		}	
	}
	*di "`allvars_sel'"	
	
	clear
	return loc allvars_sel_new `allvars_sel' 
	return loc added_vars `added_vars'
	restore
end

